<template>

  <div>

    <!-- Filters -->
    <product-class-main-filters
      :code-filter.sync="codeFilter"
      :name-filter.sync="nameFilter"
      :code-options="codeOptions"
      :name-options="nameOptions"
    />

    <!-- Table Container Card -->
    <b-card
      no-body
      class="mb-0"
    >

      <div class="m-2">

        <!-- Table Top -->
        <b-row>

          <!-- Per Page -->
          <b-col
            cols="12"
            md="6"
            class="d-flex align-items-center justify-content-start mb-1 mb-md-0"
          >
            <label>Show</label>
            <v-select
              v-model="perPage"
              :dir="$store.state.appConfig.isRTL ? 'rtl' : 'ltr'"
              :options="perPageOptions"
              :clearable="false"
              class="per-page-selector d-inline-block mx-50"
            />
            <label>entries</label>
          </b-col>

          <!-- Search -->
          <b-col
            cols="12"
            md="6"
          >
            <div class="d-flex align-items-center justify-content-end">
              <b-form-input
                v-model="searchQuery"
                class="d-inline-block mr-1"
                placeholder="Search..."
              />
              <b-button
                variant="primary"
                :to="{ name: 'information-product-class-main-add'}"
              >
                <span class="text-nowrap">新增</span>
              </b-button>
            </div>
          </b-col>
        </b-row>

      </div>

      <b-table
        ref="refProductClassMainListTable"
        class="position-relative"
        :items="fetchProductClassMains"
        responsive
        :fields="tableColumns"
        primary-key="id"
        :sort-by.sync="sortBy"
        show-empty
        empty-text="No matching records found"
        :sort-desc.sync="isSortDirDesc"
      >

        <!-- Column: code -->
        <template #cell(code)="data">
          <div class="text-nowrap">
            <span class="align-text-top text-capitalize">{{ data.item.code }}</span>
          </div>
        </template>

        <!-- Column: name -->
        <template #cell(name)="data">
          <div class="text-nowrap">
            <span class="align-text-top text-capitalize">{{ data.item.name }}</span>
          </div>
        </template>

        <!-- Column: created_at -->
        <template #cell(created_at)="data">
          <div class="text-nowrap">
            <span class="align-text-top text-capitalize">{{ data.item.created_at }}</span>
          </div>
        </template>

        <!-- Column: updated_at -->
        <template #cell(updated_at)="data">
          <div class="text-nowrap">
            <span class="align-text-top text-capitalize">{{ data.item.updated_at }}</span>
          </div>
        </template>

        <!-- Column: Actions -->
        <template #cell(actions)="data">
          <b-badge
            variant="light-secondary"
            class="cursor-pointer"
            :to="{ name: 'information-product-class-main-edit', params: { id: data.item.id } }"
          >
            <feather-icon
              icon="EditIcon"
              class="mr-25"
            />
            <span>修改</span>
          </b-badge>
          <b-badge
            variant="light-danger"
            class="cursor-pointer"
            @click="deleteProductClassMain(data.item.id, data.item.name)"
          >
            <feather-icon
              icon="TrashIcon"
              class="mr-25"
            />
            <span>刪除</span>
          </b-badge>
        </template>

      </b-table>
      <div class="mx-2 mb-2">
        <b-row>

          <b-col
            cols="12"
            sm="6"
            class="d-flex align-items-center justify-content-center justify-content-sm-start"
          >
            <span class="text-muted">Showing {{ dataMeta.from }} to {{ dataMeta.to }} of {{ dataMeta.of }} entries</span>
          </b-col>
          <!-- Pagination -->
          <b-col
            cols="12"
            sm="6"
            class="d-flex align-items-center justify-content-center justify-content-sm-end"
          >

            <b-pagination
              v-model="currentPage"
              :total-rows="totalProductClassMains"
              :per-page="perPage"
              first-number
              last-number
              class="mb-0 mt-1 mt-sm-0"
              prev-class="prev-item"
              next-class="next-item"
            >
              <template #prev-text>
                <feather-icon
                  icon="ChevronLeftIcon"
                  size="18"
                />
              </template>
              <template #next-text>
                <feather-icon
                  icon="ChevronRightIcon"
                  size="18"
                />
              </template>
            </b-pagination>

          </b-col>

        </b-row>
      </div>
    </b-card>
  </div>
</template>

<script>
import {
  BCard,
  BRow,
  BCol,
  BFormInput,
  BButton,
  BTable,
  BMedia,
  BAvatar,
  BLink,
  BBadge,
  BDropdown,
  BDropdownItem,
  BPagination,
} from 'bootstrap-vue'
import vSelect from 'vue-select'
import store from '@/store'
import { ref, onUnmounted } from '@vue/composition-api'
import { avatarText } from '@core/utils/filter'
import ProductClassMainFilters from './ProductClassMainFilters.vue'
import useProductClassMain from './useProductClassMain'
import productClassMainStoreModule from '../productClassMainStoreModule'
import ProductClassMainAddNew from './ProductClassMainAddNew.vue'

export default {
  components: {
    ProductClassMainFilters,
    ProductClassMainAddNew,

    BCard,
    BRow,
    BCol,
    BFormInput,
    BButton,
    BTable,
    BMedia,
    BAvatar,
    BLink,
    BBadge,
    BDropdown,
    BDropdownItem,
    BPagination,

    vSelect,
  },
  setup() {
    const USER_APP_STORE_MODULE_NAME = 'information'

    // Register module
    if (!store.hasModule(USER_APP_STORE_MODULE_NAME)) store.registerModule(USER_APP_STORE_MODULE_NAME, productClassMainStoreModule)

    // UnRegister on leave
    onUnmounted(() => {
      if (store.hasModule(USER_APP_STORE_MODULE_NAME)) store.unregisterModule(USER_APP_STORE_MODULE_NAME)
    })

    const {
      fetchProductClassMains,
      getOptions,
      deleteProductClassMain,
      tableColumns,
      perPage,
      currentPage,
      totalProductClassMains,
      dataMeta,
      perPageOptions,
      searchQuery,
      sortBy,
      isSortDirDesc,
      refProductClassMainListTable,
      refetchData,

      // Extra Filters
      codeFilter,
      nameFilter,
      codeOptions,
      nameOptions,
    } = useProductClassMain()

    getOptions()

    return {

      fetchProductClassMains,
      getOptions,
      deleteProductClassMain,
      tableColumns,
      perPage,
      currentPage,
      totalProductClassMains,
      dataMeta,
      perPageOptions,
      searchQuery,
      sortBy,
      isSortDirDesc,
      refProductClassMainListTable,
      refetchData,

      // Filter
      avatarText,

      // Extra Filters
      codeFilter,
      nameFilter,
      codeOptions,
      nameOptions,
    }
  },
}
</script>

<style lang="scss" scoped>
.per-page-selector {
  width: 90px;
}
</style>

<style lang="scss">
@import '~@resources/scss/vue/libs/vue-select.scss';
</style>
